[![Coverage Status](https://coveralls.io/repos/luizirber/rec_env/badge.png)](https://coveralls.io/r/luizirber/rec_env) [![Build Status](https://travis-ci.org/luizirber/rec_env.png?branch=master)](https://travis-ci.org/luizirber/rec_env) [![Requirements Status](https://requires.io/github/luizirber/rec_env/requirements.png?branch=master)](https://requires.io/github/luizirber/rec_env/requirements/?branch=master)
